EventRegister class

Mixed-in types

Constructors

EventRegister([ServerEventBook? eventBook])

Properties

eventBook ServerEventBook
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnected(ContextCallBack callBack) → void
inherited
onDisconnected(ContextCallBack callBack) → void
inherited
onEvent(String eventName, ContextCallBack callback) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited