ZapServer class

Mixed-in types

Constructors

ZapServer({dynamic address = '0.0.0.0', int port = 8000, String path = "/", bool shared = true, int backlog = 0})

Properties

address → dynamic
final
backlog int
final
eventBook ServerEventBook
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
path String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shared bool
final

Methods

close() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConnected(ContextCallBack callBack) → void
inherited
onDisconnected(ContextCallBack callBack) → void
inherited
onEvent(String eventName, ContextCallBack callback) → void
inherited
start() Future<HttpServer>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited